nxp-pac

Crates

git

Versions

lpc55s16

Flavors

Rbar

Struct Rbar 

#[repr(transparent)]
pub struct Rbar(pub u32);
MPU Region Base Address Register.

Tuple Fields

0: u32

Implementations

Source

impl Rbar

pub const fn xn(&self) -> RbarXn

The XN bit is an Execute Never bit, that indicates whether the processor can execute instructions from the region.

pub const fn set_xn(&mut self, val: RbarXn)

The XN bit is an Execute Never bit, that indicates whether the processor can execute instructions from the region.

pub const fn ap(&self) -> RbarAp

The AP[2:0] bits indicate the access and privilege properties of the region.

pub const fn set_ap(&mut self, val: RbarAp)

The AP[2:0] bits indicate the access and privilege properties of the region.

pub const fn sh(&self) -> RbarSh

For Normal memory regions, the S bit indicates whether the region is shareable. For Strongly-ordered and Device memory, the S bit is ignored.

pub const fn set_sh(&mut self, val: RbarSh)

For Normal memory regions, the S bit indicates whether the region is shareable. For Strongly-ordered and Device memory, the S bit is ignored.

pub const fn base(&self) -> u32

Contains bits[31:5] of the lower inclusive limit of the selected MPU memory region. This value is zero extended to provide the base address to be checked against.

pub const fn set_base(&mut self, val: u32)

Contains bits[31:5] of the lower inclusive limit of the selected MPU memory region. This value is zero extended to provide the base address to be checked against.