nxp-pac

Crates

git

Versions

lpc55s16

Flavors

RlarA3

Struct RlarA3 

#[repr(transparent)]
pub struct RlarA3(pub u32);
MPU Region Limit Address Register.

Tuple Fields

0: u32

Implementations

Source

impl RlarA3

pub const fn en(&self) -> bool

Enables this region.

pub const fn set_en(&mut self, val: bool)

Enables this region.

pub const fn attrindx(&self) -> u8

Attribute index. Associates a set of attributes in the MPU_MAIR0 and MPU_MAIR1 fields.

pub const fn set_attrindx(&mut self, val: u8)

Attribute index. Associates a set of attributes in the MPU_MAIR0 and MPU_MAIR1 fields.

pub const fn limit(&self) -> u32

Limit address. Contains bits[31:5] of the upper inclusive limit of the selected MPU memory region. This value is postfixed with 0x1F to provide the limit address to be checked against.

pub const fn set_limit(&mut self, val: u32)

Limit address. Contains bits[31:5] of the upper inclusive limit of the selected MPU memory region. This value is postfixed with 0x1F to provide the limit address to be checked against.