nxp-pac

Crates

git

Versions

lpc55s16

Flavors

Type

Struct Type 

#[repr(transparent)]
pub struct Type(pub u32);
The MPU Type Register indicates how many regions the MPU support. Software can use it to determine if the processor implements an MPU.

Tuple Fields

0: u32

Implementations

Source

impl Type

pub const fn separate(&self) -> bool

Indicates support for separate instruction and data address maps. RAZ. Armv8-M only supports a unified MPU.

pub const fn set_separate(&mut self, val: bool)

Indicates support for separate instruction and data address maps. RAZ. Armv8-M only supports a unified MPU.

pub const fn dregion(&self) -> u8

Number of regions supported by the MPU. If this field reads-as-zero the processor does not implement an MPU.

pub const fn set_dregion(&mut self, val: u8)

Number of regions supported by the MPU. If this field reads-as-zero the processor does not implement an MPU.