#[repr(transparent)]pub struct Rbar(pub u32);Expand description
MPU Region Base Address Register.
Tuple Fields
0: u32Implementations
Sourceimpl Rbar
impl Rbar
Sourcepub const fn xn(&self) -> RbarXn
pub const fn xn(&self) -> RbarXn
The XN bit is an Execute Never bit, that indicates whether the processor can execute instructions from the region.
Sourcepub const fn set_xn(&mut self, val: RbarXn)
pub const fn set_xn(&mut self, val: RbarXn)
The XN bit is an Execute Never bit, that indicates whether the processor can execute instructions from the region.
Sourcepub const fn ap(&self) -> RbarAp
pub const fn ap(&self) -> RbarAp
The AP[2:0] bits indicate the access and privilege properties of the region.
Sourcepub const fn set_ap(&mut self, val: RbarAp)
pub const fn set_ap(&mut self, val: RbarAp)
The AP[2:0] bits indicate the access and privilege properties of the region.
Sourcepub const fn sh(&self) -> RbarSh
pub const fn sh(&self) -> RbarSh
For Normal memory regions, the S bit indicates whether the region is shareable. For Strongly-ordered and Device memory, the S bit is ignored.
Sourcepub const fn set_sh(&mut self, val: RbarSh)
pub const fn set_sh(&mut self, val: RbarSh)
For Normal memory regions, the S bit indicates whether the region is shareable. For Strongly-ordered and Device memory, the S bit is ignored.