#[repr(transparent)]pub struct RbarA1(pub u32);Expand description
MPU Region Base Address Register.
Tuple Fields
0: u32Implementations
Sourceimpl RbarA1
impl RbarA1
Sourcepub const fn xn(&self) -> RbarA1Xn
pub const fn xn(&self) -> RbarA1Xn
The XN bit is an Execute Never bit, that indicates whether the processor can execute instructions from the region.
Sourcepub const fn set_xn(&mut self, val: RbarA1Xn)
pub const fn set_xn(&mut self, val: RbarA1Xn)
The XN bit is an Execute Never bit, that indicates whether the processor can execute instructions from the region.
Sourcepub const fn ap(&self) -> RbarA1Ap
pub const fn ap(&self) -> RbarA1Ap
The AP[2:0] bits indicate the access and privilege properties of the region.
Sourcepub const fn set_ap(&mut self, val: RbarA1Ap)
pub const fn set_ap(&mut self, val: RbarA1Ap)
The AP[2:0] bits indicate the access and privilege properties of the region.
Sourcepub const fn sh(&self) -> RbarA1Sh
pub const fn sh(&self) -> RbarA1Sh
For Normal memory regions, the S bit indicates whether the region is shareable. For Strongly-ordered and Device memory, the S bit is ignored.
Sourcepub const fn set_sh(&mut self, val: RbarA1Sh)
pub const fn set_sh(&mut self, val: RbarA1Sh)
For Normal memory regions, the S bit indicates whether the region is shareable. For Strongly-ordered and Device memory, the S bit is ignored.