#[repr(transparent)]pub struct RbarA3(pub u32);Expand description
MPU Region Base Address Register.
Tuple Fields
0: u32Implementations
Sourceimpl RbarA3
impl RbarA3
Sourcepub const fn xn(&self) -> RbarA3Xn
pub const fn xn(&self) -> RbarA3Xn
The XN bit is an Execute Never bit, that indicates whether the processor can execute instructions from the region.
Sourcepub const fn set_xn(&mut self, val: RbarA3Xn)
pub const fn set_xn(&mut self, val: RbarA3Xn)
The XN bit is an Execute Never bit, that indicates whether the processor can execute instructions from the region.
Sourcepub const fn ap(&self) -> RbarA3Ap
pub const fn ap(&self) -> RbarA3Ap
The AP[2:0] bits indicate the access and privilege properties of the region.
Sourcepub const fn set_ap(&mut self, val: RbarA3Ap)
pub const fn set_ap(&mut self, val: RbarA3Ap)
The AP[2:0] bits indicate the access and privilege properties of the region.
Sourcepub const fn sh(&self) -> RbarA3Sh
pub const fn sh(&self) -> RbarA3Sh
For Normal memory regions, the S bit indicates whether the region is shareable. For Strongly-ordered and Device memory, the S bit is ignored.
Sourcepub const fn set_sh(&mut self, val: RbarA3Sh)
pub const fn set_sh(&mut self, val: RbarA3Sh)
For Normal memory regions, the S bit indicates whether the region is shareable. For Strongly-ordered and Device memory, the S bit is ignored.