#[repr(transparent)]pub struct Type(pub u32);Expand description
The MPU Type Register indicates how many regions the MPU support. Software can use it to determine if the processor implements an MPU.
Tuple Fields
0: u32Implementations
Sourceimpl Type
impl Type
Sourcepub const fn separate(&self) -> bool
pub const fn separate(&self) -> bool
Indicates support for separate instruction and data address maps. RAZ. Armv8-M only supports a unified MPU.
Sourcepub const fn set_separate(&mut self, val: bool)
pub const fn set_separate(&mut self, val: bool)
Indicates support for separate instruction and data address maps. RAZ. Armv8-M only supports a unified MPU.
Sourcepub const fn dregion(&self) -> u8
pub const fn dregion(&self) -> u8
Number of regions supported by the MPU. If this field reads-as-zero the processor does not implement an MPU.
Sourcepub const fn set_dregion(&mut self, val: u8)
pub const fn set_dregion(&mut self, val: u8)
Number of regions supported by the MPU. If this field reads-as-zero the processor does not implement an MPU.